@@ -10,15 +10,15 @@ from django.utils import unittest
 from django_nopassword import views
 
 from django_nopassword.models import LoginCode
-from django_nopassword.utils import User
+from django_nopassword.utils import get_user_model
 
 from .models import NoUsernameUser
 
 
 class TestLoginCodes(unittest.TestCase):
     def setUp(self):
-        self.user = User.objects.create(username='test_user')
-        self.inactive_user = User.objects.create(username='inactive', is_active=False)
+        self.user = get_user_model().objects.create(username='test_user')
+        self.inactive_user = get_user_model().objects.create(username='inactive', is_active=False)
 
     def test_login_backend(self):
         self.code = LoginCode.create_code_for_user(self.user)
@@ -63,7 +63,7 @@ class TestViews(unittest.TestCase):
 
     def setUp(self):
         self.c = Client()
-        self.user = User.objects.create(username='user')
+        self.user = get_user_model().objects.create(username='user')
 
     def test_login(self):
         response = self.c.get('/accounts/login/')
@@ -72,10 +72,14 @@ class TestViews(unittest.TestCase):
         login = self.c.post('/accounts/login/?next=/secret/', {'username': self.user.username})
         self.assertEqual(login.status_code, 200)
 
-        login_with_code = self.c.get('/accounts/login-code/%s/%s/' % (self.user.username, 'wrongcode'))
+        login_with_code = self.c.get('/accounts/login-code/%s/%s/' % (self.user.username,
+                                                                      'wrongcode'))
         self.assertEqual(login_with_code.status_code, 404)
 
-        login_with_code = self.c.get('/accounts/login-code/%s/%s/' % (self.user.username, LoginCode.objects.all()[0].code))
+        login_with_code = self.c.get('/accounts/login-code/%s/%s/' % (
+            self.user.username,
+            LoginCode.objects.all()[0].code)
+        )
         self.assertEqual(login_with_code.status_code, 302)
 
         logout = self.c.get('/accounts/logout/')
